#
# spec file for package picocli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The automatic requires would be java-headless >= 9, but the
# binaries are java 8 compatible
%define __requires_exclude java-headless
Name:           picocli
Version:        4.7.6
Release:        1.2
Summary:        Tiny Command Line Interface
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://picocli.info/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-build.xml
Source2:        https://repo1.maven.org/maven2/info/%{name}/%{name}/%{version}/%{name}-%{version}.pom
Source3:        https://repo1.maven.org/maven2/info/%{name}/%{name}-codegen/%{version}/%{name}-codegen-%{version}.pom
Source4:        https://repo1.maven.org/maven2/info/%{name}/%{name}-shell-jline2/%{version}/%{name}-shell-jline2-%{version}.pom
BuildRequires:  ant
BuildRequires:  aqute-bnd
BuildRequires:  fdupes
BuildRequires:  java-devel >= 9
BuildRequires:  javapackages-local >= 6
BuildRequires:  jline >= 2
Requires:       java-headless >= 1.8
BuildArch:      noarch

%description
Java command line parser with both an annotations API and a programmatic API.
Usage help with ANSI styles and colors. Autocomplete. Nested subcommands.
Easily included as source to avoid adding a dependency.

%package codegen
Summary:        Picocli Code Generation
Group:          Development/Libraries/Java
Requires:       java-headless >= 1.8

%description codegen
Java command line parser with both an annotations API and a programmatic API.
Usage help with ANSI styles and colors. Autocomplete. Nested subcommands.
Easily included as source to avoid adding a dependency.

Tools to generate documentation, configuration, source code and other files
from a picocli model.

%package shell-jline2
Summary:        Picocli Shell JLine2
Group:          Development/Libraries/Java
Requires:       java-headless >= 1.8

%description shell-jline2
Java command line parser with both an annotations API and a programmatic API.
Usage help with ANSI styles and colors. Autocomplete. Nested subcommands.
Easily included as source to avoid adding a dependency.

Library to build interactive shell applications with JLine 2 and picocli.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%build
%{ant} \
	-Dproject.version=%{version} \
	-Djline2.jar=$(find-jar jline/jline) \
	jar javadoc

echo "-reproducible: true" >> bnd.bnd
echo "-noextraheaders: true" >> bnd.bnd
echo "-snapshot: SNAPSHOT" >> bnd.bnd

# Convert to OSGi bundle
bnd wrap \
    --force \
    --bsn %{name} \
    --version %{version} \
    --output target/%{name}-%{version}.bar \
    --properties bnd.bnd \
    target/%{name}-%{version}.jar
mv target/%{name}-%{version}.bar target/%{name}-%{version}.jar

%install
#jar
install -dm0755 %{buildroot}%{_javadir}/%{name}
install -pm0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
install -pm0644 target/%{name}-codegen-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-codegen.jar
install -pm0644 target/%{name}-shell-jline2-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-shell-jline2.jar

#pom
install -dm0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} %{SOURCE2} %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%{mvn_install_pom} %{SOURCE3} %{buildroot}%{_mavenpomdir}/%{name}/%{name}-codegen.pom
%{mvn_install_pom} %{SOURCE4} %{buildroot}%{_mavenpomdir}/%{name}/%{name}-shell-jline2.pom

%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
%add_maven_depmap %{name}/%{name}-codegen.pom %{name}/%{name}-codegen.jar -f codegen
%add_maven_depmap %{name}/%{name}-shell-jline2.pom %{name}/%{name}-shell-jline2.jar -f shell-jline2

#javadoc
install -dm0755 %{buildroot}%{_javadocdir}/%{name}
cp -r target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc README.md

%files codegen -f .mfiles-codegen

%files shell-jline2 -f .mfiles-shell-jline2

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE

%changelog
* Thu Oct 31 2024 Fridrich Strba <fstrba@suse.com>
- Update to version 4.7.6
  * Enhancements
    + PropertiesDefaultProvider should try to load properties from
    classpath (last).
    + Change log level from WARN to INFO when bean not found in
    ApplicationContext.
    + Don't show hidden commands in JLine3 command description.
    + Use ... vararg instead of array parameter to match overridden
    method signature.
  * Bugfixes:
    + defaultValue should not be applied in addition to
    user-specified value for options with a custom
    IParameterConsumer.
    + Fix NPE in jline3 Example.jar as ConfigurationPath cannot be
    null anymore.
    + fix bug for Optional<T> arguments with initial value.
    + @Option-annotated setter method not invoked with default value
    when used in mixin for both command and subcommand.
    + Custom type converter for primitive boolean options should not
    be ignored.
  * BUILD fixes:
    + fix errorprone TruthSelfEquals warnings
    + Fix broken build.
    + Fix .gitattributes related CR/LF problems.
    + Add Error Prone.
  * CLEAN fix:
    + Remove unused extra format arguments.
  * DOC fixes:
    + Fix a few typos in CommandLine's JavaDoc.
    + Clarify documentation for negatable options.
    + Clarify that ParseResult passed to IExecutionExceptionHandler
    is the top-level parse result, not the parse result of the
    subcommand that failed.
- Due to a bug in the upstream github repository, fetch sources from
  our private fork until https://github.com/remkop/picocli/pull/2347
  gets integrated upstream
* Wed Oct 30 2024 Fridrich Strba <fstrba@suse.com>
- Create a second spec file picocli-extras to be able to build
  the picocli-shell-jline3 artifact without build cycles
* Wed Oct  2 2024 Fridrich Strba <fstrba@suse.com>
- Spec file cleanup
* Mon Apr 29 2024 Fridrich Strba <fstrba@suse.com>
- The binaries are compatible with java 1.8
* Sun Sep 10 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: Do not create timestamps with bnd wrap
* Sun Aug 27 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 4.7.5
  * Enhancements:
    + Java 22 update: improve logic for detecting if the output
    stream is connected to a terminal.
    + Mask parameters in trace log when echo=false for interactive
    options and positional parameters.
  * Bugfixes:
    + Fix positional parameters bug with late-resolved arity
    variable.
    + Don't generate auto-complete for hidden attributes in
    picocli.shell.jline3.PicoCommand.
    + ArgGroup with exclusive=false and multiplicity=1 should
    require at least one option; fix regression and refine
    solution introduced in [#1848][#2030].
  * DOC fixes:
    + Improve GraalVM documentation: add
    graalvm-native-image-plugin.
    + Commit html files with LF line-endings.
- Removed patch:
  * revert-version.patch
    + not needed any more
* Sat Aug 26 2023 Fridrich Strba <fstrba@suse.com>
- Fetch sources from upstream repository, since our pull request
  https://github.com/remkop/picocli/pull/2045 has been integrated
* Tue Jun 13 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 4.7.4
  * Fixes:
    + API: Add setter for name in
    picocli.shell.jline3.PicocliCommands.
    + Enhancement: Improved feedback on mistyped subcommands
    + Enhancement: prevent
    java.nio.charset.UnsupportedCharsetException: cp0 on windows,
    and fall back to the default charset if the charset provided
    by System property sun.stdout.encoding is invalid
    + Bugfix: Option "mapFallbackValue" ignored when inherited to
    subcommand
    + Bugfix: fix issue with required options in ArgGroup becoming
    optional when combined with DefaultValueProvider
- Fetch sources using source service: this allows filter out
  binaries with spurious legal status and which we don't use for
  build
- Due to a bug in the upstream github repository, fetch sources from
  our private fork until https://github.com/remkop/picocli/pull/2045
  gets integrated upstream
- Added patch:
  * revert-version.patch
    + revert a version change between our fixed code and the
    upstream tag
* Mon Jun  5 2023 Fridrich Strba <fstrba@suse.com>
- Require java 9 for build so that we can build the module-info.java
  always
- Build all classes with source/target 8 and the module-info.java
  with release 9, which makes the jars usable with java 8 and higher
* Thu Jun  1 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to version 4.7.3
  * full changes from previous versions are in
    https://github.com/remkop/picocli/blob/v4.7.3/RELEASE-NOTES.md
- Package artifacts: picocli-{codegen,shell-jline2}
- JPMS: package module discriptors when building with java >= 9
- Take POMs from Maven Central
* Fri Jun 24 2022 Fridrich Strba <fstrba@suse.com>
- Build picocli using ant to avoid cycles
* Tue Jan 18 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 4.6.2
  * full changes from previous versions are in
    https://github.com/remkop/picocli/blob/v4.6.2/RELEASE-NOTES.md
* Fri Nov  8 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of picocli 4.0.4
